﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerWalk : MonoBehaviour {

	public float rotationSpeed = 3f;
	private float rotateY;

	public Transform groundCheckPosition;
	public float jumpPower = 200f;
	public float radius = 0.3f;
	public LayerMask groundLayer;

	private Rigidbody myBody;

	private bool isGrounded, hasJumped;

	private PlayerAnimation playerAnim;

	private float h, v;

	void Awake () {
		myBody = GetComponent<Rigidbody> ();
		playerAnim = GetComponent<PlayerAnimation> ();
	}

	void Update () {
		CheckMovement ();
		AnimatePlayer ();
		CheckForAttack ();
		CheckGroundCollisionAndJump ();
	}

	void CheckGroundCollisionAndJump() {
		isGrounded = Physics.OverlapSphere (groundCheckPosition.position,
			radius, groundLayer).Length > 0;

		if (Input.GetKeyDown (KeyCode.Space)) {
			if (isGrounded) {
				myBody.AddForce (new Vector3 (0, jumpPower, 0));
				hasJumped = true;
				playerAnim.Jumped (true);
			}
		}

	}

	void CheckForAttack() {
		if (Input.GetMouseButtonDown (0)) {
			playerAnim.Attack1 ();
		}

		if (Input.GetMouseButtonDown (1)) {
			playerAnim.Attack2 ();
		}
	}

	void CheckMovement() {
		h = Input.GetAxis ("Horizontal");
		v = Input.GetAxis ("Vertical");

		rotateY -= h * rotationSpeed;

		transform.localRotation = Quaternion.AngleAxis (rotateY, Vector3.up);
	}

	void AnimatePlayer() {
		if (v != 0) {
			playerAnim.PlayerWalk (true);
		} else {
			playerAnim.PlayerWalk (false);
		}
	}

	void OnCollisionEnter(Collision target) {
		if (target.gameObject.tag == "Ground") {
			if (hasJumped) {
				hasJumped = false;
				playerAnim.Jumped (false);
			}
		}
	}

} // class


































